@@ -15,8 +15,11 @@ if( not not eval "require JSON::Any" ) {
 
 
 use LWP::UserAgent;
+use Log::Log4perl qw(:easy);
 use t::lib::utils;
 
+Log::Log4perl -> easy_init($INFO);
+
 ###
 # for testing
 ###
